.. currentmodule:: nnfigs

============
Introduction
============

.. include:: ../README.rst
   :start-line: 4

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`